@@ -1,13 +1,9 @@
 # -*- coding: utf-8 -*-
 
 from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class UploadTokenRequest(NamespacedResource):
     """
     OpenShift UploadTokenRequest object.
